==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Modify/Divide/ts/Divide_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Divide</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz linię, łuk lub okrąg</translation>
    </message>
    <message>
        <location filename="../Divide.js" line="+68"/>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation type="unfinished">Wskaż punkt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify second point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż drugi punkt
Wskaż dugi punkt odległości</translatorcomment>
        <translation type="unfinished">Wskaż drugi punkt</translation>
    </message>
    <message>
        <source>Cutting point is not on entity.</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Punkt cięcia nie jest na obiekcie.</translatorcomment>
        <translation type="obsolete">Punkt cięcia nie jest na obiekcie.</translation>
    </message>
    <message>
        <location filename="../DivideInit.js" line="+2"/>
        <source>&amp;Divide</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Podzie&amp;l
Podziel &amp;2</translatorcomment>
        <translation type="unfinished">Podzie&amp;l</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Modify/Divide/ts/Divide_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Divide</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz linię, łuk lub okrąg</translation>
    </message>
    <message>
        <location filename="../Divide.js" line="+66"/>
        <source>Choose line, arc, circle, ellipse, spline or polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation type="unfinished">Wskaż punkt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify second point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż drugi punkt
Wskaż dugi punkt odległości</translatorcomment>
        <translation type="unfinished">Wskaż drugi punkt</translation>
    </message>
    <message>
        <source>Cutting point is not on entity.</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Punkt cięcia nie jest na obiekcie.</translatorcomment>
        <translation type="obsolete">Punkt cięcia nie jest na obiekcie.</translation>
    </message>
    <message>
        <location filename="../DivideInit.js" line="+2"/>
        <source>&amp;Divide</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Podzie&amp;l
Podziel &amp;2</translatorcomment>
        <translation type="unfinished">Podzie&amp;l</translation>
    </message>
</context>
</TS>
